@@ -7,7 +7,12 @@ class OneshotProcess(SubProcess):
 
     @asyncio.coroutine
     def process_started_co(self):
-        yield from self.timed_wait(self.process_timeout, self._exit_timeout)
+        result = yield from self.timed_wait(self.process_timeout, self._exit_timeout)
+        if result is not None and not result.normal_exit:
+            if self.ignore_failures:
+                warn("{0} (ignored) failure on start-up with result '{1}'".format(self.name, result))
+            else:
+                raise Exception("{0} failed on start-up with result '{1}'".format(self.name, result))
         
     def _exit_timeout(self):
         service = self.service
